@@ -12,8 +12,7 @@ import httpx
 
 
 class EapiCommandError(RuntimeError):
-    """
-    Exception class for EAPI command errors.
+    """Exception class for EAPI command errors.
 
     Attributes
     ----------
