@@ -21,7 +21,7 @@ def build_test_id(val: dict[str, Any]) -> str:
 
 
 def pytest_generate_tests(metafunc: pytest.Metafunc) -> None:
-    """Generate ANTA testts unit tests dynamically during test collection.
+    """Generate ANTA tests unit tests dynamically during test collection.
 
     It will parametrize test cases based on the `DATA` data structure defined in `tests.units.anta_tests` modules.
     See `tests/units/anta_tests/README.md` for more information on how to use it.
